# -*- text -*-
##
##  eap.conf -- Configuration for EAP types (PEAP, TTLS, etc.)
##

eap {
	{% if config.default_eap_type == "reject" %}
	default_eap_type = tls
	{% else %}
	default_eap_type = {{config.default_eap_type|safe}}
	{% endif %}
	timer_expire     = {{config.mods.eap.timer_expire|safe}}
	ignore_unknown_eap_types = no
	cisco_accounting_username_bug = {{config.mods.eap.cisco_accounting_username_bug|safe}}
	max_sessions = ${max_requests}
	tls-config tls-common {
		private_key_password = {{config.certs.server.passphrase|safe}}
		private_key_file = ${certdir}/server.pem
		certificate_file = ${certdir}/server.pem
		ca_file = ${cadir}/ca.pem
		auto_chain = {{config.mods.eap.tls_common.auto_chain|safe}}
		dh_file = ${certdir}/dh
		random_file = /dev/urandom
		fragment_size = {{config.mods.eap.tls_common.fragment_size|safe}}
		include_length = {{config.mods.eap.tls_common.include_length|safe}}
		check_crl = no
		check_all_crl = no
		ca_path = ${cadir}/
		allow_expired_crl = {{config.mods.eap.tls_common.allow_expired_crl|safe}}
	#	check_cert_issuer = "/C=GB/ST=Berkshire/L=Newbury/O=My Company Ltd"
	#	check_cert_cn = %{User-Name}
		cipher_list = {{config.mods.eap.tls_common.cipher_list|safe}}
		cipher_server_preference = {{config.mods.eap.tls_common.cipher_server_preference|safe}}
		disable_tlsv1_2 = {{config.mods.eap.tls_common.disable_tlsv1_2|safe}}
		disable_tlsv1_1 = {{config.mods.eap.tls_common.disable_tlsv1_1|safe}}
		disable_tlsv1 = {{config.mods.eap.tls_common.disable_tlsv1|safe}}
		tls_min_version = {{config.mods.eap.tls_common.tls_min_version|safe}}
		tls_max_version = {{config.mods.eap.tls_common.tls_max_version|safe}}
		ecdh_curve = {{config.mods.eap.tls_common.ecdh_curve|safe}}
		cache {
			enable = {{config.mods.eap.tls_common.cache.enable|safe}}
			lifetime = {{config.mods.eap.tls_common.cache.lifetime|safe}} # hours
			name = {{config.mods.eap.tls_common.cache.name|safe}}
			#persist_dir = "${logdir}/tlscache"
		}
		verify {
	#		skip_if_ocsp_ok = no
	#		tmpdir = /tmp/radiusd
	#		client = "/path/to/openssl verify -CApath ${..ca_path} %{TLS-Client-Cert-Filename}"
		}

		ocsp {
			enable = no
			override_cert_url = yes
			url = "http://127.0.0.1/ocsp/"
			# use_nonce = yes
			# timeout = 0
			# softfail = no
		}
	}

	{% if config.default_eap_type == "reject" %}# dummy tls
	tls {
		tls = tls-common
	#	virtual_server = check-eap-tls
	}
	{% else %}# disable peap
	{% if config.method.eaptls %}# enable tls
	tls {
		tls = tls-common
	#	virtual_server = check-eap-tls
	}
	{% else %}# disable peap
	{% endif %}
	{% endif %}

	{% if config.method.peap %}# enable peap
	peap {
		tls = tls-common
		default_eap_type = {{config.mods.eap.peap.default_eap_type|safe}}
		copy_request_to_tunnel = {{config.mods.eap.peap.copy_request_to_tunnel|safe}}
		use_tunneled_reply = no
	#	proxy_tunneled_request_as_eap = yes
		virtual_server = "inner-tunnel"
	#	soh = yes
	#	soh_virtual_server = "soh-server"
		require_client_cert = {{config.mods.eap.peap.require_client_cert|safe}}
	}
	{% else %}# disable peap
	{% endif %}

	mschapv2 {
		send_error = {{config.mods.eap.mschapv2.send_error|safe}}
		identity = {{config.mods.eap.mschapv2.identity|safe}}
	}
	
	{% if config.default_eap_type == "reject" %}rejected{% endif %}
}
